@@ -86,14 +86,21 @@ def totimestamp(dt, epoch=datetime.datetime(1970,1,1,0,0,0,0,pytz.UTC)):
 
 
 def format_pace(x,pos=None):
-    secstime = datetime.datetime.fromtimestamp(x+0.05)
+    try:
+        secstime = datetime.datetime.fromtimestamp(x+0.05)
+    except OverFlowError:
+        date = datetime.datetime(1970, 1, 1) + datetime.timedelta(seconds-x)
+
     stime =  '%s.%i' % (secstime.strftime("%M:%S"), secstime.microsecond/100000)
     return stime
 
 
 def format_time(x,pos=None):
+    try:
+        secstime = datetime.datetime.fromtimestamp(x+0.05)
+    except OverFlowError:
+        date = datetime.datetime(1970, 1, 1) + datetime.timedelta(seconds-x)
 
-    secstime = datetime.datetime.fromtimestamp(x+0.05)
     if x < 3600:
         secstime = secstime.replace(hour=0)
 
